@@ -58,7 +58,7 @@ function(model, ...)
     stop("in RCLSMIX!", call. = FALSE); return(NA)
   }
 
-  model@Zp <- as.factor(output$Z)
+  model@Zp <- factor(output$Z, levels = levels(model@Zt))
 
   rm(list = ls()[!(ls() %in% c("model"))])
 
@@ -125,7 +125,7 @@ function(model, ...)
     stop("in RCLSMIX!", call. = FALSE); return(NA)
   }
 
-  model@Zp <- as.factor(output$Z)
+  model@Zp <- factor(output$Z, levels = levels(model@Zt))
 
   rm(list = ls()[!(ls() %in% c("model"))])
 
@@ -141,10 +141,12 @@ function(model,
 {
   digits <- getOption("digits"); options(digits = 15)
 
-  message("RCLSMIX Version 2.10.3")
+  message("RCLSMIX Version 2.11.0")
 
   flush.console()
 
+  levels <- levels(Zt)
+
   model <- new(model,
     x = x,
     Dataset = Dataset,
@@ -152,7 +154,8 @@ function(model,
 
   model <- RCLSMIX(model = model, ...)
 
-  model@Zp <- factor(model@Zp, levels = levels(model@Zt))
+  levels(model@Zt) <- levels
+  levels(model@Zp) <- levels
 
   model@CM <- table(model@Zt, model@Zp)
 
@@ -184,7 +187,7 @@ function(model,
 {
   digits <- getOption("digits"); options(digits = 15)
 
-  message("BFSMIX Version 2.10.3")
+  message("BFSMIX Version 2.11.0")
 
   flush.console()
 
