@@ -1,99 +1,132 @@
-setMethod("boot", 
+setMethod("boot",
           signature(x = "REBMIX"),
 function(x,
   rseed,
   pos,
   Bootstrap,
-  B, 
+  B,
   n,
-  replace, 
+  replace,
   prob, ...)
 {
   digits <- getOption("digits"); options(digits = 15)
-  
-  model <- new("REBMIX.boot", 
+
+  model <- new("REBMIX.boot",
     x = x,
-    rseed = rseed, 
+    rseed = rseed,
     pos = pos,
     Bootstrap = Bootstrap,
     B = B,
     n = n,
     replace = replace,
     prob = prob)
-    
+
   if (model@Bootstrap == .rebmix.boot$Bootstrap[1]) {
     bsample <- RNGMIX(Dataset.name = paste("bsample_", 1:model@B, sep = ""), rseed = rseed,
       n = ceiling(model@n * as.numeric(model@x@w[[model@pos]])),
-      Theta = model@x@Theta[[model@pos]], ...)
-      
+      Theta = model@x@Theta[[model@pos]])
+
     Dataset <- bsample@Dataset
   }
   else
   if (model@Bootstrap == .rebmix.boot$Bootstrap[2]) {
     dataset <- as.matrix(model@x@Dataset[[model@pos]])
-    
+
     Dataset <- list()
-    
+
     for (i in 1:model@B) {
       R1 <- sample.int(n = nrow(dataset), size = model@n, replace = replace, prob = if (length(prob) == 0) NULL else prob)
-      
+
       Dataset[[i]] <- as.data.frame(dataset[R1,], stringsAsFactors = FALSE)
     }
   }
-  
+
   if (length(model@x@theta1) > 0) {
     theta1 <- model@x@theta1; theta1[is.na(theta1)] <- 0
   }
   else {
     theta1 <- numeric()
-  }    
-    
+  }
+
   if (length(model@x@theta2) > 0) {
     theta2 <- model@x@theta2; theta2[is.na(theta2)] <- 0
   }
   else {
     theta2 <- numeric()
-  }  
-    
+  }
+
   d <- length(model@x@Variables)
   
+  # cmax.
+  
+  cmax <- list(...)$cmax
+
+  if (is.null(cmax) || (length(cmax) == 0)) cmax <- as.numeric(model@x@summary[model@pos, "cmax"])
+
+  if (!is.wholenumber(cmax)) {
+    stop(sQuote("cmax"), " integer is requested!", call. = FALSE)
+  }
+
+  if (cmax < 1) {
+    stop(sQuote("cmax"), " must be greater than 0!", call. = FALSE)
+  }
+  
+  # cmin.
+  
+  cmin <- list(...)$cmin
+
+  if (is.null(cmin) || (length(cmin) == 0)) cmin <- as.numeric(model@x@summary[model@pos, "cmin"])
+
+  if (!is.wholenumber(cmin)) {
+    stop(sQuote("cmin"), " integer is requested!", call. = FALSE)
+  }
+
+  if (cmin < 1) {
+    stop(sQuote("cmin"), " must be greater than 0!", call. = FALSE)
+  }
+
+  if (cmin > cmax) {
+    stop(sQuote("cmin"), " must be less or equal than ", cmax, "!", call. = FALSE)
+  }  
+
   bsampleest <- REBMIX(Dataset = Dataset,
     Preprocessing = as.character(model@x@summary[model@pos, "Preprocessing"]),
-    cmax = as.numeric(model@x@summary[model@pos, "cmax"]),
+    cmax = cmax,
+    cmin = cmin,
     Criterion = as.character(model@x@summary[model@pos, "Criterion"]),
     Variables = model@x@Variables,
     pdf = model@x@pdf,
     theta1 = theta1,
     theta2 = theta2,
     K = eval(parse(text = as.character(model@x@summary[model@pos, "K"]))),
-    y0 = model@x@y0,    
+    y0 = model@x@y0,
     ymin = model@x@ymin,
     ymax = model@x@ymax,
     ar = as.numeric(model@x@summary[model@pos, "ar"]),
     Restraints = as.character(model@x@summary[model@pos, "Restraints"]))
 
   freq <- table(as.numeric(bsampleest@summary$c))
-  
+
   c <- as.integer(names(freq)[which.max(freq)])
-  
+
   model@c <- as.numeric(bsampleest@summary$c)
   model@c.se <- sd(model@c)
-  model@c.cv <- model@c.se / mean(model@c)  
-  
+  model@c.cv <- model@c.se / mean(model@c)
+
   w <- bsampleest@w[model@c == c]
-  
+
   Theta <- bsampleest@Theta[model@c == c]
-  
+
   model@c.mode <- c
   model@c.prob <- length(w) / model@B
-  
+
   model@w <- matrix(unlist(w), ncol = c, byrow = TRUE)
-  
-  colnames(model@w) <- paste("comp", if (c > 1) 1:c else "", sep = "")
+
+  colnames(model@w) <- paste(1:c, sep = "")
   rownames(model@w) <- paste(which(bsampleest@summary$c == c), sep = "")
-  
-  model@w.se <- apply(model@w, 2, sd)
-  model@w.cv <- model@w.se / apply(model@w, 2, mean)
+
+  model@w.se <- as.vector(apply(model@w, 2, sd))
+  model@w.cv <- as.vector(model@w.se / apply(model@w, 2, mean))
 
   for (i in 1:model@c.mode) {
     theta1 <- paste("theta1.",  i, sep = "")
@@ -106,16 +139,16 @@ function(x,
 
     model@Theta[[theta1]] <- matrix(model@Theta[[theta1]], ncol = d, byrow = TRUE)
 
-    colnames(model@Theta[[theta1]]) <- paste(1:d, sep = "")
+    colnames(model@Theta[[theta1]]) <- NULL
     rownames(model@Theta[[theta1]]) <- paste(which(bsampleest@summary$c == c), sep = "")
 
     theta1.se <- paste("theta1.",  i, ".se", sep = "")
     theta1.cv <- paste("theta1.",  i, ".cv", sep = "")
 
-    model@Theta.se[[theta1.se]] <- apply(model@Theta[[theta1]], 2, sd)
-    model@Theta.cv[[theta1.cv]] <- model@Theta.se[[theta1.se]] / apply(model@Theta[[theta1]], 2, mean)
+    model@Theta.se[[theta1.se]] <- as.vector(apply(model@Theta[[theta1]], 2, sd))
+    model@Theta.cv[[theta1.cv]] <- as.vector(model@Theta.se[[theta1.se]] / apply(model@Theta[[theta1]], 2, mean))
   }
-  
+
   for (i in 1:model@c.mode) {
     theta2 <- paste("theta2.",  i, sep = "")
 
@@ -127,120 +160,153 @@ function(x,
 
     model@Theta[[theta2]] <- matrix(model@Theta[[theta2]], ncol = d, byrow = TRUE)
 
-    colnames(model@Theta[[theta2]]) <- paste(1:d, sep = "")
+    colnames(model@Theta[[theta2]]) <- NULL
     rownames(model@Theta[[theta2]]) <- paste(which(bsampleest@summary$c == c), sep = "")
 
     theta2.se <- paste("theta2.",  i, ".se", sep = "")
     theta2.cv <- paste("theta2.",  i, ".cv", sep = "")
 
-    model@Theta.se[[theta2.se]] <- apply(model@Theta[[theta2]], 2, sd)
-    model@Theta.cv[[theta2.cv]] <- model@Theta.se[[theta2.se]] / apply(model@Theta[[theta2]], 2, mean)
+    model@Theta.se[[theta2.se]] <- as.vector(apply(model@Theta[[theta2]], 2, sd))
+    model@Theta.cv[[theta2.cv]] <- as.vector(model@Theta.se[[theta2.se]] / apply(model@Theta[[theta2]], 2, mean))
   }
-  
-  options(digits = digits)  
 
-  rm(list = ls()[!(ls() %in% c("model"))]) 
-   
-  return(model)  
+  options(digits = digits)
+
+  rm(list = ls()[!(ls() %in% c("model"))])
+
+  return(model)
 }) ## boot
 
-setMethod("boot", 
+setMethod("boot",
           signature(x = "REBMVNORM"),
 function(x,
   rseed,
   pos,
   Bootstrap,
-  B, 
+  B,
   n,
-  replace, 
+  replace,
   prob, ...)
 {
   digits <- getOption("digits"); options(digits = 15)
-  
-  model <- new("REBMVNORM.boot", 
+
+  model <- new("REBMVNORM.boot",
     x = x,
-    rseed = rseed, 
+    rseed = rseed,
     pos = pos,
     Bootstrap = Bootstrap,
     B = B,
     n = n,
     replace = replace,
     prob = prob)
-    
+
   if (model@Bootstrap == .rebmix.boot$Bootstrap[1]) {
     bsample <- RNGMIX(model = "RNGMVNORM", Dataset.name = paste("bsample_", 1:model@B, sep = ""), rseed = rseed,
       n = ceiling(model@n * as.numeric(model@x@w[[model@pos]])),
-      Theta = model@x@Theta[[model@pos]], ...)
-      
+      Theta = model@x@Theta[[model@pos]])
+
     Dataset <- bsample@Dataset
   }
   else
   if (model@Bootstrap == .rebmix.boot$Bootstrap[2]) {
     dataset <- as.matrix(model@x@Dataset[[model@pos]])
-    
+
     Dataset <- list()
-    
+
     for (i in 1:model@B) {
       R1 <- sample.int(n = nrow(dataset), size = model@n, replace = replace, prob = if (length(prob) == 0) NULL else prob)
-      
+
       Dataset[[i]] <- as.data.frame(dataset[R1,], stringsAsFactors = FALSE)
     }
   }
-  
+
   if (length(model@x@theta1) > 0) {
     theta1 <- model@x@theta1; theta1[is.na(theta1)] <- 0
   }
   else {
     theta1 <- numeric()
-  }    
-    
+  }
+
   if (length(model@x@theta2) > 0) {
     theta2 <- model@x@theta2; theta2[is.na(theta2)] <- 0
   }
   else {
     theta2 <- numeric()
-  }  
-    
+  }
+
   d <- length(model@x@Variables)
+
+  # cmax.
   
+  cmax <- list(...)$cmax
+
+  if (is.null(cmax) || (length(cmax) == 0)) cmax <- as.numeric(model@x@summary[model@pos, "cmax"])
+
+  if (!is.wholenumber(cmax)) {
+    stop(sQuote("cmax"), " integer is requested!", call. = FALSE)
+  }
+
+  if (cmax < 1) {
+    stop(sQuote("cmax"), " must be greater than 0!", call. = FALSE)
+  }
+  
+  # cmin.
+  
+  cmin <- list(...)$cmin
+
+  if (is.null(cmin) || (length(cmin) == 0)) cmin <- as.numeric(model@x@summary[model@pos, "cmin"])
+
+  if (!is.wholenumber(cmin)) {
+    stop(sQuote("cmin"), " integer is requested!", call. = FALSE)
+  }
+
+  if (cmin < 1) {
+    stop(sQuote("cmin"), " must be greater than 0!", call. = FALSE)
+  }
+
+  if (cmin > cmax) {
+    stop(sQuote("cmin"), " must be less or equal than ", cmax, "!", call. = FALSE)
+  }  
+
   bsampleest <- REBMIX(model = "REBMVNORM",
     Dataset = Dataset,
     Preprocessing = as.character(model@x@summary[model@pos, "Preprocessing"]),
-    cmax = as.numeric(model@x@summary[model@pos, "cmax"]),
+    cmax = cmax,
+    cmin = cmin,
     Criterion = as.character(model@x@summary[model@pos, "Criterion"]),
     Variables = model@x@Variables,
     pdf = model@x@pdf,
     theta1 = theta1,
     theta2 = theta2,
     K = eval(parse(text = as.character(model@x@summary[model@pos, "K"]))),
-    y0 = model@x@y0,    
+    y0 = model@x@y0,
     ymin = model@x@ymin,
     ymax = model@x@ymax,
     ar = as.numeric(model@x@summary[model@pos, "ar"]),
     Restraints = as.character(model@x@summary[model@pos, "Restraints"]))
 
   freq <- table(as.numeric(bsampleest@summary$c))
-  
+
   c <- as.integer(names(freq)[which.max(freq)])
-  
+
   model@c <- as.numeric(bsampleest@summary$c)
   model@c.se <- sd(model@c)
-  model@c.cv <- model@c.se / mean(model@c)  
-  
+  model@c.cv <- model@c.se / mean(model@c)
+
   w <- bsampleest@w[model@c == c]
-  
+
   Theta <- bsampleest@Theta[model@c == c]
-  
+
   model@c.mode <- c
   model@c.prob <- length(w) / model@B
-  
+
   model@w <- matrix(unlist(w), ncol = c, byrow = TRUE)
-  
-  colnames(model@w) <- paste("comp", if (c > 1) 1:c else "", sep = "")
+
+  colnames(model@w) <- paste(1:c, sep = "")
   rownames(model@w) <- paste(which(bsampleest@summary$c == c), sep = "")
-  
-  model@w.se <- apply(model@w, 2, sd)
-  model@w.cv <- model@w.se / apply(model@w, 2, mean)
+
+  model@w.se <- as.vector(apply(model@w, 2, sd))
+  model@w.cv <- as.vector(model@w.se / apply(model@w, 2, mean))
 
   for (i in 1:model@c.mode) {
     theta1 <- paste("theta1.",  i, sep = "")
@@ -253,16 +319,16 @@ function(x,
 
     model@Theta[[theta1]] <- matrix(model@Theta[[theta1]], ncol = d, byrow = TRUE)
 
-    colnames(model@Theta[[theta1]]) <- paste(1:d, sep = "")
+    colnames(model@Theta[[theta1]]) <- NULL
     rownames(model@Theta[[theta1]]) <- paste(which(bsampleest@summary$c == c), sep = "")
 
     theta1.se <- paste("theta1.",  i, ".se", sep = "")
     theta1.cv <- paste("theta1.",  i, ".cv", sep = "")
 
-    model@Theta.se[[theta1.se]] <- apply(model@Theta[[theta1]], 2, sd)
-    model@Theta.cv[[theta1.cv]] <- model@Theta.se[[theta1.se]] / apply(model@Theta[[theta1]], 2, mean)
+    model@Theta.se[[theta1.se]] <- as.vector(apply(model@Theta[[theta1]], 2, sd))
+    model@Theta.cv[[theta1.cv]] <- as.vector(model@Theta.se[[theta1.se]] / apply(model@Theta[[theta1]], 2, mean))
   }
-  
+
   for (i in 1:model@c.mode) {
     theta2 <- paste("theta2.",  i, sep = "")
 
@@ -273,20 +339,20 @@ function(x,
     }
 
     model@Theta[[theta2]] <- matrix(model@Theta[[theta2]], ncol = d * d, byrow = TRUE)
-    
-    colnames(model@Theta[[theta2]]) <- paste(rep(1:d, each = d), rep(1:d, d), sep = "-")
+
+    colnames(model@Theta[[theta2]]) <- NULL
     rownames(model@Theta[[theta2]]) <- paste(which(bsampleest@summary$c == c), sep = "")
 
     theta2.se <- paste("theta2.",  i, ".se", sep = "")
     theta2.cv <- paste("theta2.",  i, ".cv", sep = "")
 
-    model@Theta.se[[theta2.se]] <- apply(model@Theta[[theta2]], 2, sd)
-    model@Theta.cv[[theta2.cv]] <- model@Theta.se[[theta2.se]] / apply(model@Theta[[theta2]], 2, mean)
+    model@Theta.se[[theta2.se]] <- as.vector(apply(model@Theta[[theta2]], 2, sd))
+    model@Theta.cv[[theta2.cv]] <- as.vector(model@Theta.se[[theta2.se]] / apply(model@Theta[[theta2]], 2, mean))
   }
-  
-  options(digits = digits)  
 
-  rm(list = ls()[!(ls() %in% c("model"))]) 
-   
-  return(model)  
+  options(digits = digits)
+
+  rm(list = ls()[!(ls() %in% c("model"))])
+
+  return(model)
 }) ## boot
