@@ -115,6 +115,18 @@ function(x,
 
         fi <- fi * output$f
       }
+      else
+      if (pdf[[i]][j] == .rebmix$pdf[10]) {
+        output <- .C(C_RGumbelPdf,
+          n = as.integer(n),
+          y = as.double(Dataset[, j]),
+          Mean = as.double(theta1[[i]][j]),
+          Beta = as.double(theta2[[i]][j]),
+          f = double(n),
+          PACKAGE = "rebmix")
+
+        fi <- fi * output$f      
+      }
     }
 
     f <- f + as.numeric(w[i]) * fi
