@@ -7,6 +7,7 @@
 
 #include "base.h"
 #include "rebmvnormf.h"
+#include "emf.h"
 
 // Perform necessary initializations.
 
@@ -20,7 +21,7 @@ int Rebmvnorm::Initialize()
 
     var_mul_ = (FLOAT)0.0625;
 
-    kmax_ = ((FLOAT)1.0 + (FLOAT)1.0 / length_pdf_) * (FLOAT)pow((FLOAT)n_, (FLOAT)1.0 / ((FLOAT)1.0 + (FLOAT)1.0 / length_pdf_));
+    kmax_ = (int)floor(((FLOAT)1.0 + (FLOAT)1.0 / length_pdf_) * (FLOAT)pow((FLOAT)n_, (FLOAT)1.0 / ((FLOAT)1.0 + (FLOAT)1.0 / length_pdf_)));
 
     Error = GammaInv((FLOAT)1.0 - (FLOAT)2.0 * p_value_, (FLOAT)2.0, length_pdf_ / (FLOAT)2.0, &ChiSqr_);
 
@@ -139,7 +140,7 @@ S1:;
 
     Error = NULL == Cinv; if (Error) goto E0;
 
-    if (nl >= length_pdf_) {
+    if (nl > length_pdf_) {
         for (i = 0; i < length_pdf_; i++) {
             Sum = (FLOAT)0.0;
 
@@ -226,7 +227,6 @@ S1:;
 
     epsilon = (FLOAT)exp(-(FLOAT)2.0 * (LogSqrtPi2 + logflm / length_pdf_) - RigidTheta->Theta_[3][0] / length_pdf_);
 
-//  if (epsilon > (FLOAT)1.0) {
     RigidTheta->Theta_[3][0] += length_pdf_ * (FLOAT)log(epsilon);
 
     for (i = 0; i < length_pdf_; i++) {
@@ -242,13 +242,12 @@ S1:;
             RigidTheta->Theta_[2][p] = RigidTheta->Theta_[2][q] /= epsilon;
         }
     }
-//  }
 
     Error = LooseTheta->Memmove(RigidTheta);
 
     if (Error) goto E0;
 
-    if (Restraints_ == rtRigid) goto E0;
+    if ((Restraints_ == rtRigid) || (nl <= length_pdf_)) goto E0;
 
     // Loose restraints.
 
@@ -416,7 +415,7 @@ S1:;
 
     Error = NULL == Cinv; if (Error) goto E0;
 
-    if (nl >= length_pdf_) {
+    if (nl > length_pdf_) {
         for (i = 0; i < length_pdf_; i++) {
             Sum = (FLOAT)0.0;
 
@@ -503,7 +502,6 @@ S1:;
 
     epsilon = (FLOAT)exp(-(FLOAT)2.0 * (LogSqrtPi2 + logflm / length_pdf_) - RigidTheta->Theta_[3][0] / length_pdf_);
 
-//  if (epsilon > (FLOAT)1.0) {
     RigidTheta->Theta_[3][0] += length_pdf_ * (FLOAT)log(epsilon);
 
     for (i = 0; i < length_pdf_; i++) {
@@ -519,13 +517,12 @@ S1:;
             RigidTheta->Theta_[2][p] = RigidTheta->Theta_[2][q] /= epsilon;
         }
     }
-//  }
 
     Error = LooseTheta->Memmove(RigidTheta);
 
     if (Error) goto E0;
 
-    if (Restraints_ == rtRigid) goto E0;
+    if ((Restraints_ == rtRigid) || (nl <= length_pdf_)) goto E0;
 
     // Loose restraints.
 
@@ -677,7 +674,7 @@ S0:;
 
     Error = NULL == Cinv; if (Error) goto E0;
 
-    if (nl >= length_pdf_) {
+    if (nl > length_pdf_) {
         for (i = 0; i < length_pdf_; i++) {
             Sum = (FLOAT)0.0;
 
@@ -764,7 +761,6 @@ S0:;
 
     epsilon = (FLOAT)exp(-(FLOAT)2.0 * (LogSqrtPi2 + logflm / length_pdf_) - RigidTheta->Theta_[3][0] / length_pdf_);
 
-//  if (epsilon > (FLOAT)1.0) {
     RigidTheta->Theta_[3][0] += length_pdf_ * (FLOAT)log(epsilon);
 
     for (i = 0; i < length_pdf_; i++) {
@@ -780,13 +776,12 @@ S0:;
             RigidTheta->Theta_[2][p] = RigidTheta->Theta_[2][q] /= epsilon;
         }
     }
-//  }
-
+    
     Error = LooseTheta->Memmove(RigidTheta);
 
     if (Error) goto E0;
 
-    if (Restraints_ == rtRigid) goto E0;
+    if ((Restraints_ == rtRigid) || (nl <= length_pdf_)) goto E0;
 
     // Loose restraints.
 
@@ -894,55 +889,54 @@ int Rebmvnorm::EnhancedEstimationKNN(FLOAT                **Y,         // Pointe
 
     if (Error) goto E0;
 
-    if (nl >= length_pdf_) {
-        for (i = 0; i < length_pdf_; i++) {
-            EnhanTheta->pdf_[i] = pfNormal;
-
-            Sum = (FLOAT)0.0;
-
-            for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
-                Sum += Y[j][length_pdf_] * Y[j][i];
-            }
-
-            EnhanTheta->Theta_[0][i] = Sum / nl;
-
-            o = i * length_pdf_ + i;
-
-            Sum = (FLOAT)0.0;
-
-            for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
-                Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][i] - EnhanTheta->Theta_[0][i]);
-            }
-
-            EnhanTheta->Theta_[1][o] = Sum / nl;
-
-            if (EnhanTheta->Theta_[1][o] < RigidTheta->Theta_[1][o] * var_mul_) {
-                Error = 1; goto E0;
-            }
-
-            for (ii = 0; ii < i; ii++) {
-                Sum = (FLOAT)0.0;
-
-                for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
-                    Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][ii] - EnhanTheta->Theta_[0][ii]);
-                }
-
-                EnhanTheta->Theta_[1][i * length_pdf_ + ii] = EnhanTheta->Theta_[1][ii * length_pdf_ + i] = Sum / nl;
-            }
-        }
-
-        Error = Cholinvdet(length_pdf_, EnhanTheta->Theta_[1], EnhanTheta->Theta_[2], EnhanTheta->Theta_[3]);
-
-        if (Error) goto E0;
-
-        Error = LooseTheta->Memmove(EnhanTheta);
-
-        if (Error) goto E0;
-    }
-    else {
+    if (nl <= (FLOAT)1.0) {
         Error = 1; goto E0;
     }
 
+    for (i = 0; i < length_pdf_; i++) {
+        EnhanTheta->pdf_[i] = pfNormal;
+
+        Sum = (FLOAT)0.0;
+
+        for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
+            Sum += Y[j][length_pdf_] * Y[j][i];
+        }
+
+        EnhanTheta->Theta_[0][i] = Sum / nl;
+
+        o = i * length_pdf_ + i;
+
+        Sum = (FLOAT)0.0;
+
+        for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
+            Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][i] - EnhanTheta->Theta_[0][i]);
+        }
+
+        EnhanTheta->Theta_[1][o] = Sum / nl;
+
+        for (ii = 0; ii < i; ii++) {
+            Sum = (FLOAT)0.0;
+
+            for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
+                Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][ii] - EnhanTheta->Theta_[0][ii]);
+            }
+
+            EnhanTheta->Theta_[1][i * length_pdf_ + ii] = EnhanTheta->Theta_[1][ii * length_pdf_ + i] = Sum / nl;
+        }
+    }
+
+    Error = Cholinvdet(length_pdf_, EnhanTheta->Theta_[1], EnhanTheta->Theta_[2], EnhanTheta->Theta_[3]);
+
+    if (Error) goto E0;
+
+    if (*EnhanTheta->Theta_[3] < *RigidTheta->Theta_[3] + (FLOAT)log(var_mul_)) {
+        Error = 1; goto E0;
+    }
+
+    Error = LooseTheta->Memmove(EnhanTheta);
+
+    if (Error) goto E0;
+
 E0: if (EnhanTheta) delete EnhanTheta;
 
     return Error;
@@ -968,55 +962,54 @@ int Rebmvnorm::EnhancedEstimationKDE(FLOAT                **Y,         // Pointe
 
     if (Error) goto E0;
 
-    if (nl >= length_pdf_) {
-        for (i = 0; i < length_pdf_; i++) {
-            EnhanTheta->pdf_[i] = pfNormal;
-
-            Sum = (FLOAT)0.0;
-
-            for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
-                Sum += Y[j][length_pdf_] * Y[j][i];
-            }
-
-            EnhanTheta->Theta_[0][i] = Sum / nl;
-
-            o = i * length_pdf_ + i;
-
-            Sum = (FLOAT)0.0;
-
-            for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
-                Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][i] - EnhanTheta->Theta_[0][i]);
-            }
-
-            EnhanTheta->Theta_[1][o] = Sum / nl;
-
-            if (EnhanTheta->Theta_[1][o] < RigidTheta->Theta_[1][o] * var_mul_) {
-                Error = 1; goto E0;
-            }
-
-            for (ii = 0; ii < i; ii++) {
-                Sum = (FLOAT)0.0;
-
-                for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
-                    Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][ii] - EnhanTheta->Theta_[0][ii]);
-                }
-
-                EnhanTheta->Theta_[1][i * length_pdf_ + ii] = EnhanTheta->Theta_[1][ii * length_pdf_ + i] = Sum / nl;
-            }
-        }
-
-        Error = Cholinvdet(length_pdf_, EnhanTheta->Theta_[1], EnhanTheta->Theta_[2], EnhanTheta->Theta_[3]);
-
-        if (Error) goto E0;
-
-        Error = LooseTheta->Memmove(EnhanTheta);
-
-        if (Error) goto E0;
-    }
-    else {
+    if (nl <= (FLOAT)1.0) {
         Error = 1; goto E0;
     }
 
+    for (i = 0; i < length_pdf_; i++) {
+        EnhanTheta->pdf_[i] = pfNormal;
+
+        Sum = (FLOAT)0.0;
+
+        for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
+            Sum += Y[j][length_pdf_] * Y[j][i];
+        }
+
+        EnhanTheta->Theta_[0][i] = Sum / nl;
+
+        o = i * length_pdf_ + i;
+
+        Sum = (FLOAT)0.0;
+
+        for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
+            Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][i] - EnhanTheta->Theta_[0][i]);
+        }
+
+        EnhanTheta->Theta_[1][o] = Sum / nl;
+
+        for (ii = 0; ii < i; ii++) {
+            Sum = (FLOAT)0.0;
+
+            for (j = 0; j < n_; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
+                Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][ii] - EnhanTheta->Theta_[0][ii]);
+            }
+
+            EnhanTheta->Theta_[1][i * length_pdf_ + ii] = EnhanTheta->Theta_[1][ii * length_pdf_ + i] = Sum / nl;
+        }
+    }
+
+    Error = Cholinvdet(length_pdf_, EnhanTheta->Theta_[1], EnhanTheta->Theta_[2], EnhanTheta->Theta_[3]);
+
+    if (Error) goto E0;
+
+    if (*EnhanTheta->Theta_[3] < *RigidTheta->Theta_[3] + (FLOAT)log(var_mul_)) {
+        Error = 1; goto E0;
+    }
+
+    Error = LooseTheta->Memmove(EnhanTheta);
+
+    if (Error) goto E0;
+
 E0: if (EnhanTheta) delete EnhanTheta;
 
     return Error;
@@ -1043,55 +1036,54 @@ int Rebmvnorm::EnhancedEstimationH(int                  k,           // Total nu
 
     if (Error) goto E0;
 
-    if (nl >= length_pdf_) {
-        for (i = 0; i < length_pdf_; i++) {
-            EnhanTheta->pdf_[i] = pfNormal;
-
-            Sum = (FLOAT)0.0;
-
-            for (j = 0; j < k; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
-                Sum += Y[j][length_pdf_] * Y[j][i];
-            }
-
-            EnhanTheta->Theta_[0][i] = Sum / nl;
-
-            o = i * length_pdf_ + i;
-
-            Sum = (FLOAT)0.0;
-
-            for (j = 0; j < k; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
-                Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][i] - EnhanTheta->Theta_[0][i]);
-            }
-
-            EnhanTheta->Theta_[1][o] = Sum / nl;
-
-            if (EnhanTheta->Theta_[1][o] < RigidTheta->Theta_[1][o] * var_mul_) {
-                Error = 1; goto E0;
-            }
-
-            for (ii = 0; ii < i; ii++) {
-                Sum = (FLOAT)0.0;
-
-                for (j = 0; j < k; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
-                    Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][ii] - EnhanTheta->Theta_[0][ii]);
-                }
-
-                EnhanTheta->Theta_[1][i * length_pdf_ + ii] = EnhanTheta->Theta_[1][ii * length_pdf_ + i] = Sum / nl;
-            }
-        }
-
-        Error = Cholinvdet(length_pdf_, EnhanTheta->Theta_[1], EnhanTheta->Theta_[2], EnhanTheta->Theta_[3]);
-
-        if (Error) goto E0;
-
-        Error = LooseTheta->Memmove(EnhanTheta);
-
-        if (Error) goto E0;
-    }
-    else {
+    if (nl <= (FLOAT)1.0) {
         Error = 1; goto E0;
     }
 
+    for (i = 0; i < length_pdf_; i++) {
+        EnhanTheta->pdf_[i] = pfNormal;
+
+        Sum = (FLOAT)0.0;
+
+        for (j = 0; j < k; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
+            Sum += Y[j][length_pdf_] * Y[j][i];
+        }
+
+        EnhanTheta->Theta_[0][i] = Sum / nl;
+
+        o = i * length_pdf_ + i;
+
+        Sum = (FLOAT)0.0;
+
+        for (j = 0; j < k; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
+            Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][i] - EnhanTheta->Theta_[0][i]);
+        }
+
+        EnhanTheta->Theta_[1][o] = Sum / nl;
+
+        for (ii = 0; ii < i; ii++) {
+            Sum = (FLOAT)0.0;
+
+            for (j = 0; j < k; j++) if (Y[j][length_pdf_] > FLOAT_MIN) {
+                Sum += Y[j][length_pdf_] * (Y[j][i] - EnhanTheta->Theta_[0][i]) * (Y[j][ii] - EnhanTheta->Theta_[0][ii]);
+            }
+
+            EnhanTheta->Theta_[1][i * length_pdf_ + ii] = EnhanTheta->Theta_[1][ii * length_pdf_ + i] = Sum / nl;
+        }
+    }
+
+    Error = Cholinvdet(length_pdf_, EnhanTheta->Theta_[1], EnhanTheta->Theta_[2], EnhanTheta->Theta_[3]);
+
+    if (Error) goto E0;
+
+    if (*EnhanTheta->Theta_[3] < *RigidTheta->Theta_[3] + (FLOAT)log(var_mul_)) {
+        Error = 1; goto E0;
+    }
+
+    Error = LooseTheta->Memmove(EnhanTheta);
+
+    if (Error) goto E0;
+
 E0: if (EnhanTheta) delete EnhanTheta;
 
     return Error;
@@ -1448,3 +1440,44 @@ int Rebmvnorm::DegreesOffreedom(int c,                  // Number of components.
 
     return Error;
 } // DegreesOffreedom
+
+/// Panic Branislav: Runs the EM algorithm or its variant for the initial parameters assesed by the REBMIX algorithm.
+
+int Rebmvnorm::ExpectationMaximizationStep(int                  c,          // Number of components.
+                                           FLOAT                *W,         // Component weights.  
+                                           CompnentDistribution **MixTheta, // Mixture parameters.
+                                           int                  *n_iter)    // Number of iterations. 
+{
+    int j, Error = 0;
+
+    Em *em = NULL;
+
+    em = new Em;
+
+    Error = em == NULL;
+
+    if (Error) goto E0;
+
+    Error = em->Initialize(c, W, MixTheta, EM_TOL_, EM_max_iter_, EM_variant_, EM_accel_, EM_ar_);
+
+    if (Error) goto E0;
+
+    Error = em->Run(Y_, n_);
+
+    if (Error) goto E0;
+
+    for (j = 0; j < c; j++)	{
+        W[j] = em->W_[j];
+
+        MixTheta[j]->Memmove(em->MixTheta_[j]);
+    }
+
+    *n_iter = em->n_iter_;
+
+E0: if (em != NULL) delete em;
+
+    return Error;
+}
+
+/// End
+
